@@ -14,6 +14,7 @@
 
 import collections
 import json
+import socket
 
 from nose import tools
 from pymemcache.client import Client, MemcacheUnknownCommandError
@@ -26,6 +27,9 @@ class MockSocket(object):
         self.recv_bufs = collections.deque(recv_bufs)
         self.send_bufs = []
         self.closed = False
+        self.timeouts = []
+        self.connections = []
+        self.socket_options = []
 
     def sendall(self, value):
         self.send_bufs.append(value)
@@ -39,6 +43,23 @@ class MockSocket(object):
             raise value
         return value
 
+    def settimeout(self, timeout):
+        self.timeouts.append(timeout)
+
+    def connect(self, server):
+        self.connections.append(server)
+
+    def setsockopt(self, level, option, value):
+        self.socket_options.append((level, option, value))
+
+
+class MockSocketModule(object):
+    def socket(self, family, type):
+        return MockSocket([])
+
+    def __getattr__(self, name):
+        return getattr(socket, name)
+
 
 def test_set_success():
     client = Client(None)
@@ -131,7 +152,7 @@ def test_set_exception():
 def test_set_many_success():
     client = Client(None)
     client.sock = MockSocket(['STORED\r\n'])
-    result = client.set_many({'key' : 'value'}, noreply=False)
+    result = client.set_many({'key': 'value'}, noreply=False)
     tools.assert_equal(result, True)
     tools.assert_equal(client.sock.closed, False)
     tools.assert_equal(len(client.sock.send_bufs), 1)
@@ -142,7 +163,7 @@ def test_set_many_exception():
     client.sock = MockSocket(['STORED\r\n', Exception('fail')])
 
     def _set():
-        client.set_many({'key' : 'value', 'other' : 'value'}, noreply=False)
+        client.set_many({'key': 'value', 'other': 'value'}, noreply=False)
 
     tools.assert_raises(Exception, _set)
     tools.assert_equal(client.sock, None)
@@ -284,7 +305,6 @@ def test_cr_nl_boundaries():
     result = client.get_many(['key1', 'key2'])
     tools.assert_equals(result, {'key1': 'value1', 'key2': 'value2'})
 
-
     client.sock = MockSocket(['VALUE key1 0 6\r\n',
                               'value1\r\n',
                               'VALUE key2 0 6\r\n',
@@ -489,6 +509,7 @@ def test_serialization():
         'set key 0 0 20 noreply\r\n{"a": "b", "c": "d"}\r\n'
     ])
 
+
 def test_stats():
     client = Client(None)
     client.sock = MockSocket(['STAT fake_stats 1\r\n', 'END\r\n'])
@@ -498,6 +519,7 @@ def test_stats():
     ])
     tools.assert_equal(result, {'fake_stats': 1})
 
+
 def test_stats_with_args():
     client = Client(None)
     client.sock = MockSocket(['STAT fake_stats 1\r\n', 'END\r\n'])
@@ -507,6 +529,7 @@ def test_stats_with_args():
     ])
     tools.assert_equal(result, {'fake_stats': 1})
 
+
 def test_stats_conversions():
     client = Client(None)
     client.sock = MockSocket([
@@ -540,3 +563,27 @@ def test_stats_conversions():
         'version': '1.4.14',
     }
     tools.assert_equal(result, expected)
+
+
+def test_socket_connect():
+    server = ("example.com", 11211)
+
+    client = Client(server, socket_module=MockSocketModule())
+    client._connect()
+    tools.assert_equal(client.sock.connections, [server])
+
+    timeout = 2
+    connect_timeout = 3
+    client = Client(server, connect_timeout=connect_timeout, timeout=timeout,
+                    socket_module=MockSocketModule())
+    client._connect()
+    tools.assert_equal(client.sock.timeouts, [connect_timeout, timeout])
+
+    client = Client(server, socket_module=MockSocketModule())
+    client._connect()
+    tools.assert_equal(client.sock.socket_options, [])
+
+    client = Client(server, socket_module=MockSocketModule(), no_delay=True)
+    client._connect()
+    tools.assert_equal(client.sock.socket_options, [(socket.IPPROTO_TCP,
+                                                     socket.TCP_NODELAY, 1)])
